@@ -141,9 +141,10 @@ class MathTestCase(PluginTestCase):
 
     def testCalcMemoryError(self):
         self.assertRegexp('calc ' + '('*10000,
-            '(too much recursion'  # cpython < 3.10
-            '|too many nested parentheses'  # cpython >= 3.10
-            '|parenthesis is never closed)'  # pypy
+            r"(too much recursion"  # cpython < 3.10
+            r"|too many nested parentheses"  # cpython >= 3.10
+            r"|parenthesis is never closed"  # pypy for python < 3.10
+            r"|'\(' was never closed)"  # pypy for python >= 3.10
         )
 
     def testICalc(self):
