@@ -31,14 +31,39 @@
 from supybot.test import *
 
 class NetworkTestCase(PluginTestCase):
-    plugins = ['Network', 'Utilities']
+    plugins = ['Network', 'Utilities', 'String', 'Misc']
     def testNetworks(self):
         self.assertNotError('networks')
 
     def testCommand(self):
         self.assertResponse('network command %s echo 1' % self.irc.network,
                             '1')
+        # empty args should be allowed, see
+        # https://github.com/progval/Limnoria/issues/1541
+        self.assertResponse('network command %s len ""' % self.irc.network, '0')
 
+    def testCommandRoutesBackToCaller(self):
+        self.otherIrc = getTestIrc("testnet1")
+        # This will fail with timeout if the response never comes back
+        self.assertResponse(
+            'network command testnet1 echo $network', 'testnet1')
+
+    def testCommandRoutesErrorsBackToCaller(self):
+        self.otherIrc = getTestIrc("testnet2")
+        self.assertRegexp(
+            f'network command testnet2 re s/.*// test',
+            'I tried to send you an empty message')
+
+    def testCommandRoutesMoreBackToCaller(self):
+        self.otherIrc = getTestIrc("testnet3")
+        self.assertNotError('clearmores')
+        self.assertError('more')
+        self.assertRegexp(
+            f'network command testnet3 echo {"Hello"*300}',
+            r'Hello.*\(\d+ more messages\)')
+        self.assertRegexp(
+            'more',
+            r'Hello.*\(\d+ more messages\)')
 
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
 
